PreCommitConfig

Struct PreCommitConfig 

pub struct PreCommitConfig {
    pub generate_readmes: bool,
    pub rustfmt: bool,
    pub cargo_lock: bool,
    pub arborium: bool,
    pub edition_2024: bool,
    pub external_path_deps: bool,
    pub internal_dev_deps_release_plz: bool,
}
Configuration for pre-commit hooks.

Fields

generate_readmes: bool

Deprecated: README generation has been removed from captain. If enabled, captain will print a recommendation to use cargo-reedme.

rustfmt: bool

Format staged Rust files with rustfmt.

cargo_lock: bool

Stage Cargo.lock changes automatically.

arborium: bool

Create arborium-header.html files for enhanced rustdoc syntax highlighting.

edition_2024: bool

Require Rust edition 2024 in all workspace crates.

external_path_deps: bool

Check for path dependencies pointing outside the workspace. These are typically local development overrides that should not be committed.

internal_dev_deps_release_plz: bool

Check for internal dev-dependencies that can break release-plz.